@@ -22,8 +22,6 @@
 
 #include "datamodeltest.h"
 
-#include "modeltest.h"
-
 #include "massifdata/parser.h"
 #include "massifdata/filedata.h"
 #include "massifdata/snapshotitem.h"
@@ -34,13 +32,16 @@
 #include "visualizer/detailedcostmodel.h"
 #include "visualizer/datatreemodel.h"
 
-#include <QtCore/QFile>
-#include <QtTest/QTest>
-#include <QtCore/QDebug>
+#include <QAbstractItemModelTester>
+#include <QFile>
+#include <QTest>
+#include <QDebug>
 
 #include <KConfigGroup>
 #include <KSharedConfig>
 
+#include <memory>
+
 QTEST_MAIN(DataModelTest)
 
 using namespace Massif;
@@ -52,13 +53,13 @@ void DataModelTest::parseFile()
     QVERIFY(file.open(QIODevice::ReadOnly));
 
     Parser parser;
-    QScopedPointer<FileData> scopedData(parser.parse(&file));
-    FileData* data = scopedData.data();
+    std::unique_ptr<FileData> scopedData(parser.parse(&file));
+    FileData* data = scopedData.get();
     QVERIFY(data);
 
     {
         TotalCostModel* model = new TotalCostModel(this);
-        new ModelTest(model, this);
+        new QAbstractItemModelTester(model, this);
         model->setSource(data);
         QVERIFY(model->rowCount() == data->snapshots().size());
         for ( int r = 0; r < model->rowCount(); ++r ) {
@@ -67,12 +68,12 @@ void DataModelTest::parseFile()
             }
         }
         // remove data
-        model->setSource(0);
+        model->setSource(nullptr);
     }
 
     {
         DetailedCostModel* model = new DetailedCostModel(this);
-        new ModelTest(model, this);
+        new QAbstractItemModelTester(model, this);
         model->setSource(data);
         for ( int r = 0; r < model->rowCount(); ++r ) {
             for ( int c = 0; c < model->columnCount(); ++c ) {
@@ -84,16 +85,16 @@ void DataModelTest::parseFile()
             }
         }
         // remove data
-        model->setSource(0);
+        model->setSource(nullptr);
     }
 
     {
         DataTreeModel* model = new DataTreeModel(this);
-        new ModelTest(model, this);
+        new QAbstractItemModelTester(model, this);
         model->setSource(data);
         QVERIFY(model->rowCount() == data->snapshots().size());
         // remove data
-        model->setSource(0);
+        model->setSource(nullptr);
     }
 
 }
@@ -169,8 +170,8 @@ void DataModelTest::bigMem()
     QVERIFY(file.open(QIODevice::ReadOnly));
 
     Parser parser;
-    QScopedPointer<FileData> scopedData(parser.parse(&file));
-    FileData* data = scopedData.data();
+    std::unique_ptr<FileData> scopedData(parser.parse(&file));
+    FileData* data = scopedData.get();
     QVERIFY(data);
 
     QCOMPARE(data->snapshots().count(), 1);
@@ -178,3 +179,5 @@ void DataModelTest::bigMem()
     QCOMPARE(data->peak()->memHeapExtra(), quint64(5021305211));
     QCOMPARE(data->peak()->memStacks(), quint64(5021305212));
 }
+
+#include "moc_datamodeltest.cpp"
